@@ -10,6 +10,7 @@
 #' dates.
 #'
 #' @param x an object of class c14_date_list
+#' @param quiet suppress warning about the removal of dates without coordinates
 #'
 #' @return an object of class sf
 #'
@@ -25,27 +26,39 @@
 #'
 #' @rdname as.sf
 #'
-as.sf <- function(x) {
+as.sf <- function(x, quiet = FALSE) {
   UseMethod("as.sf")
 }
 
 #' @rdname as.sf
 #' @export
-as.sf.default <- function(x) {
+as.sf.default <- function(x, quiet = FALSE) {
   stop("x is not an object of class c14_date_list")
 }
 
 #' @rdname as.sf
 #' @export
-as.sf.c14_date_list <- function(x) {
+as.sf.c14_date_list <- function(x, quiet = FALSE) {
 
   check_if_packages_are_available("sf")
 
   x %>% check_if_columns_are_present(c("lat", "lon"))
 
+  x %<>% remove_dates_without_coordinates(quiet)
+
   x_sf <- sf::st_sfc(sf::st_multipoint(as.matrix(x[,c('lon','lat')])), crs = sf::st_crs(4326)) %>%
     sf::st_cast("POINT") %>%
     sf::st_sf(data = x, geom = .)
 
   return(x_sf)
 }
+
+#### helper functions ####
+remove_dates_without_coordinates <- function(x, quiet) {
+  if (((is.na(x[["lat"]]) | is.na(x[["lon"]])) %>% any) & !quiet) {
+    warning("Dates without coordinates were removed.")
+  }
+  x %>% dplyr::filter(
+    !is.na(.data[["lat"]]) & !is.na(.data[["lon"]])
+  ) %>% return()
+}
